@@ -1,3 +1,5 @@
+import os
+
 import pretty_errors
 # from .widgets import timer
 
@@ -79,6 +81,10 @@ class Cli:
         from .ann import milvus
         return milvus(**kwargs)
 
+    @staticmethod
+    def latexocr():
+        os.system("latexocr")
+
 
 def fire_commands():
     import fire
