@@ -16,20 +16,24 @@ class CloneProgress(RemoteProgress):
               end='', flush=True)
 
 
-def clone(url: str, repo_name=None, branch=None):
+def clone(url: str, save_path=None, branch=None, gh_proxy=False):
     url = url.strip()
-    if repo_name is None:
-        repo_name = url.split('/')[-1][:-len('.git')]
+    repo_name = url.split('/')[-1][:-len('.git')]
     if url.startswith('git'):
-        git_proxy_dir = url
+        git_proxy_dir = url.strip()
     else:
-        git_proxy_dir = f"https://ghproxy.com/{url.strip()}"
+        git_proxy_dir = f"https://ghproxy.com/{url.strip()}" if gh_proxy else url.strip()
     print(rgb_string(f"Cloning into '{repo_name}' ...", color=color_const.green))
-    Repo.clone_from(git_proxy_dir, to_path=repo_name, branch=branch, progress=CloneProgress())
+    to_path = save_path if save_path else repo_name
+    print(git_proxy_dir)
+    Repo.clone_from(git_proxy_dir, to_path=to_path, branch=branch, progress=CloneProgress())
 
 
-def clone_cmd(url: str):
-    os.system(f"git clone https://ghproxy.com/{url.strip()}")
+def clone_cmd(url: str, save_path=None, gh_proxy=False):
+    to_path = save_path if save_path else ""
+    url = url.strip()
+    gh_url = f"https://ghproxy.com/{url}" if gh_proxy else url
+    os.system(f"git clone {gh_url} {to_path}")
 
 
 if __name__ == "__main__":
